@@ -1,4 +1,4 @@
-from logtools.filelog import LogFile
+from basic_logtools.filelog import LogFile
 
 
 """
@@ -6,7 +6,7 @@ Esta es una pruea de uso de de LogFile bajo distintas situaciones
 """
 if __name__ == "__main__":
     log = LogFile("testsuma",
-                  "22_MAYO_2020",
+                  'csn',
                   "pineda",
                   path="./test_logfile/")
     print("Path->", log.file_path)
@@ -21,3 +21,4 @@ if __name__ == "__main__":
         result_2 = b/c
     except Exception as e:
         log.exception("Error en la dvisión %s" %e)
+    log.close()
